@@ -11,18 +11,17 @@ def wiki_page_reference_role(role, rawtext, text, lineno, inliner,
         wikipath, rest = text.split(u':', 1)
     except:
         wikipath, rest = text, text
-    context = inliner.document.settings.context # VersionContent instance
-    if not (context.cw_etype == 'VersionContent'
-            and context.repository.reverse_content_repo):
+    vcwiki = inliner.document.settings.context
+    if 'wikipath' not in vcwiki._cw.form:
         return [nodes.Text(rest)], []
-    vcwiki = context.repository.reverse_content_repo[0]
+    my_path = vcwiki.vcpage_path(vcwiki._cw.form['wikipath'])
     # Allow users to link to a page with file extension
     ext = '.' + vcwiki.content_file_extension
     if wikipath.endswith(ext):
         wikipath = wikipath[:-len(ext)]
     # Return url and markup options
     if not wikipath.startswith('/'):
-        vcpath = posixp.join(context.content_for[0].directory, wikipath)
+        vcpath = posixp.join(posixp.dirname(my_path), wikipath)
     else:
         vcpath = wikipath[1:]
     vcpath = posixp.normpath(vcpath)
