@@ -16,12 +16,12 @@ class RevisionDiffService(Service):
 
     def call(self, repo_eid, path, rev1, rev2):
         repo = self._cw.entity_from_eid(repo_eid)
-        hdrepo = bridge.repository_handler(repo)
-        filepath = os.path.join(hdrepo.path, path)
+        adapter = repo.cw_adapt_to('VCSRepo')
+        filepath = os.path.join(adapter.path, path)
         try:
-            with hglib.open(hdrepo.path) as repo:
-                out_diff = repo.diff(files=[filepath.encode(repo.encoding)],
-                                     revs=[rev1, rev2], git=True, unified=5)
+            with adapter.hgrepo() as hgrepo:
+                out_diff = hgrepo.diff(files=[filepath.encode(repo.encoding)],
+                                       revs=[rev1, rev2], git=True, unified=5)
             return out_diff
         except hglib.error.ServerError:
             return None
